==> scala-k8s-objects_sjs1_2.12-0.3.0-sources.jar: io/k8s/api/storage/v1/VolumeAttachmentStatus.scala <==
package io.k8s.api.storage.v1

import dev.hnaderi.k8s.utils._

/** VolumeAttachmentStatus is the status of a VolumeAttachment request. */
final case class VolumeAttachmentStatus(
  attached : Boolean,
  attachError : Option[io.k8s.api.storage.v1.VolumeError] = None,
  attachmentMetadata : Option[Map[String, String]] = None,
  detachError : Option[io.k8s.api.storage.v1.VolumeError] = None
) {

  /** Returns a new data with attached set to new value */
  def withAttached(value: Boolean) : VolumeAttachmentStatus = copy(attached = value)
  /** transforms attached to result of function */
  def mapAttached(f: Boolean => Boolean) : VolumeAttachmentStatus = copy(attached = f(attached))

  /** Returns a new data with attachError set to new value */
  def withAttachError(value: io.k8s.api.storage.v1.VolumeError) : VolumeAttachmentStatus = copy(attachError = Some(value))
  /** if attachError has a value, transforms to the result of function*/
  def mapAttachError(f: io.k8s.api.storage.v1.VolumeError => io.k8s.api.storage.v1.VolumeError) : VolumeAttachmentStatus = copy(attachError = attachError.map(f))

  /** Returns a new data with attachmentMetadata set to new value */
  def withAttachmentMetadata(value: Map[String, String]) : VolumeAttachmentStatus = copy(attachmentMetadata = Some(value))
  /** Adds new values to attachmentMetadata */
  def addAttachmentMetadata(newValues: (String, String)*) : VolumeAttachmentStatus = copy(attachmentMetadata = Some(attachmentMetadata.fold(newValues.toMap)(_ ++ newValues)))
  /** if attachmentMetadata has a value, transforms to the result of function*/
  def mapAttachmentMetadata(f: Map[String, String] => Map[String, String]) : VolumeAttachmentStatus = copy(attachmentMetadata = attachmentMetadata.map(f))

  /** Returns a new data with detachError set to new value */
  def withDetachError(value: io.k8s.api.storage.v1.VolumeError) : VolumeAttachmentStatus = copy(detachError = Some(value))
  /** if detachError has a value, transforms to the result of function*/
  def mapDetachError(f: io.k8s.api.storage.v1.VolumeError => io.k8s.api.storage.v1.VolumeError) : VolumeAttachmentStatus = copy(detachError = detachError.map(f))
}

object VolumeAttachmentStatus {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.storage.v1.VolumeAttachmentStatus, T] = new Encoder[io.k8s.api.storage.v1.VolumeAttachmentStatus, T] {
        def apply(o: io.k8s.api.storage.v1.VolumeAttachmentStatus) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("attached", o.attached)
            .write("attachError", o.attachError)
            .write("attachmentMetadata", o.attachmentMetadata)
            .write("detachError", o.detachError)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, VolumeAttachmentStatus] = new Decoder[T, VolumeAttachmentStatus] {
      def apply(t: T): Either[String, VolumeAttachmentStatus] = for {
          obj <- ObjectReader(t)
          attached <- obj.read[Boolean]("attached")
          attachError <- obj.readOpt[io.k8s.api.storage.v1.VolumeError]("attachError")
          attachmentMetadata <- obj.readOpt[Map[String, String]]("attachmentMetadata")
          detachError <- obj.readOpt[io.k8s.api.storage.v1.VolumeError]("detachError")
      } yield VolumeAttachmentStatus (
          attached = attached,
          attachError = attachError,
          attachmentMetadata = attachmentMetadata,
          detachError = detachError
        )
    }
}

==> scala-k8s-objects_sjs1_2.13-0.5.0-sources.jar: io/k8s/api/storage/v1/VolumeAttachmentStatus.scala <==
package io.k8s.api.storage.v1

import dev.hnaderi.k8s.utils._

/** VolumeAttachmentStatus is the status of a VolumeAttachment request. */
final case class VolumeAttachmentStatus(
  attached : Boolean,
  attachError : Option[io.k8s.api.storage.v1.VolumeError] = None,
  attachmentMetadata : Option[Map[String, String]] = None,
  detachError : Option[io.k8s.api.storage.v1.VolumeError] = None
) {

  /** Returns a new data with attached set to new value */
  def withAttached(value: Boolean) : VolumeAttachmentStatus = copy(attached = value)
  /** transforms attached to result of function */
  def mapAttached(f: Boolean => Boolean) : VolumeAttachmentStatus = copy(attached = f(attached))

  /** Returns a new data with attachError set to new value */
  def withAttachError(value: io.k8s.api.storage.v1.VolumeError) : VolumeAttachmentStatus = copy(attachError = Some(value))
  /** if attachError has a value, transforms to the result of function*/
  def mapAttachError(f: io.k8s.api.storage.v1.VolumeError => io.k8s.api.storage.v1.VolumeError) : VolumeAttachmentStatus = copy(attachError = attachError.map(f))

  /** Returns a new data with attachmentMetadata set to new value */
  def withAttachmentMetadata(value: Map[String, String]) : VolumeAttachmentStatus = copy(attachmentMetadata = Some(value))
  /** Adds new values to attachmentMetadata */
  def addAttachmentMetadata(newValues: (String, String)*) : VolumeAttachmentStatus = copy(attachmentMetadata = Some(attachmentMetadata.fold(newValues.toMap)(_ ++ newValues)))
  /** if attachmentMetadata has a value, transforms to the result of function*/
  def mapAttachmentMetadata(f: Map[String, String] => Map[String, String]) : VolumeAttachmentStatus = copy(attachmentMetadata = attachmentMetadata.map(f))

  /** Returns a new data with detachError set to new value */
  def withDetachError(value: io.k8s.api.storage.v1.VolumeError) : VolumeAttachmentStatus = copy(detachError = Some(value))
  /** if detachError has a value, transforms to the result of function*/
  def mapDetachError(f: io.k8s.api.storage.v1.VolumeError => io.k8s.api.storage.v1.VolumeError) : VolumeAttachmentStatus = copy(detachError = detachError.map(f))
}

object VolumeAttachmentStatus {

    implicit val encoder : Encoder[io.k8s.api.storage.v1.VolumeAttachmentStatus] = new Encoder[io.k8s.api.storage.v1.VolumeAttachmentStatus] {
        def apply[T : Builder](o: io.k8s.api.storage.v1.VolumeAttachmentStatus) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("attached", o.attached)
            .write("attachError", o.attachError)
            .write("attachmentMetadata", o.attachmentMetadata)
            .write("detachError", o.detachError)
            .build
        }
    }

    implicit val decoder: Decoder[VolumeAttachmentStatus] = new Decoder[VolumeAttachmentStatus] {
      def apply[T : Reader](t: T): Either[String, VolumeAttachmentStatus] = for {
          obj <- ObjectReader(t)
          attached <- obj.read[Boolean]("attached")
          attachError <- obj.readOpt[io.k8s.api.storage.v1.VolumeError]("attachError")
          attachmentMetadata <- obj.readOpt[Map[String, String]]("attachmentMetadata")
          detachError <- obj.readOpt[io.k8s.api.storage.v1.VolumeError]("detachError")
      } yield VolumeAttachmentStatus (
          attached = attached,
          attachError = attachError,
          attachmentMetadata = attachmentMetadata,
          detachError = detachError
        )
    }
}
